searchData={"items":[{"type":"module","title":"Surface.Components.Form","doc":"Defines a **form** that lets the user submit information.\n\nProvides a wrapper for `Phoenix.HTML.Form.form_for/3`. Additionally,\nadds the form instance that is returned by `form_for/3` into the context,\nmaking it available to any child input.\n\nAll options passed via `opts` will be sent to `form_for/3`, `for`\nand `action` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.html"},{"type":"module","title":"Properties - Surface.Components.Form","doc":"* **id** *:string* - The ID of the form attribute.\nIf an ID is given, all form inputs will also be prefixed by the given ID.\nRequired to enable form recovery following crashes or disconnects.\n\n* **for** *:any, required: true* - Atom or changeset to inform the form data\n* **action** *:string, default: \"#\"* - URL to where the form is submitted\n* **as** *:atom* - The server side parameter in which all parameters will be gathered.\n* **method** *:string* - Method to be used when submitting the form.\n* **multipart** *:boolean, default: false* - When true, sets enctype to \"multipart/form-data\". Required when uploading files.\n* **csrf_token** *:any* - For \"post\" requests, the form tag will automatically include an input\ntag with name _csrf_token. When set to false, this is disabled.\n\n* **trigger_action** *:boolean* - Trigger a standard form submit on DOM patch to the URL specified in the form's standard action\nattribute.\nThis is useful to perform pre-final validation of a LiveView form submit before posting to a\ncontroller route for operations that require Plug session mutation.\n\n* **errors** *:keyword* - Keyword list of errors for the form.\n* **opts** *:keyword, default: []* - Keyword list with options to be passed down to `Phoenix.HTML.Tag.tag/2`\n* **class** *:css_class* - Class or classes to apply to the form","ref":"Surface.Components.Form.html#module-properties"},{"type":"module","title":"Slots - Surface.Components.Form","doc":"* **default, arg: %{form: :form}** - The content of the ` `","ref":"Surface.Components.Form.html#module-slots"},{"type":"module","title":"Events - Surface.Components.Form","doc":"* **change** - Triggered when the form is changed\n* **submit** - Triggered when the form is submitted\n* **auto_recover** - Triggered when the form is being recovered.\nUse this event to enable specialized recovery when extra recovery handling\non the server is required.","ref":"Surface.Components.Form.html#module-events"},{"type":"function","title":"Surface.Components.Form.render/1","doc":"","ref":"Surface.Components.Form.html#render/1"},{"type":"module","title":"Surface.Components.Link.Button","doc":"Generates a button that uses a regular HTML form to submit to the given URL.\n\nUseful to ensure that links that change data are not triggered by search engines and other spidering software.\n\nProvides similar capabilities to Phoenix's built-in `button/2` function.\n\nOptions `label` and `class` can be set directly and will override anything in `opts`.\nAll other options are forwarded to the underlying   tag.","ref":"Surface.Components.Link.Button.html"},{"type":"module","title":"Examples - Surface.Components.Link.Button","doc":"```\n \n\n \n   user \n \n```","ref":"Surface.Components.Link.Button.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Link.Button","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **to** *:any, required: true* - The page to link to\n* **method** *:atom, default: :post* - The method to use with the button\n* **id** *:string* - Id to apply to the button\n* **class** *:css_class* - Class or classes to apply to the button\n* **label** *:string* - The label for the generated ` ` element, if no content (default slot) is provided.\n\n* **opts** *:keyword, default: []* - Additional attributes to add onto the generated element","ref":"Surface.Components.Link.Button.html#module-properties"},{"type":"module","title":"Slots - Surface.Components.Link.Button","doc":"* **default** - The content of the generated ` ` element. If no content is provided,\nthe value of property `label` is used instead.","ref":"Surface.Components.Link.Button.html#module-slots"},{"type":"module","title":"Events - Surface.Components.Link.Button","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Link.Button.html#module-events"},{"type":"function","title":"Surface.Components.Link.Button.render/1","doc":"","ref":"Surface.Components.Link.Button.html#render/1"},{"type":"module","title":"Surface.Components.LiveFileInput","doc":"Wrapper around Phoenix LiveView's built-in\n`live_file_input/2` function.\n\nThe parent LiveView, or LiveComponent must `allow_uploads` during mount:\n\n```elixir\n  def mount(socket) do\n    socket = allow_upload(socket, :avatar, accept: ~w(.json), max_entries: 1)\n    {:ok, socket}\n  end\n```\n\nSee Phoenix.LiveView [Uploads documentation](https://hexdocs.pm/phoenix_live_view/uploads.html#content)","ref":"Surface.Components.LiveFileInput.html"},{"type":"module","title":"Properties - Surface.Components.LiveFileInput","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **upload** *:struct, required: true* - Upload specified via `allow_upload`\n* **class** *:css_class* - The CSS class for the generated ` ` element\n* **opts** *:keyword, default: []* - Keyword list with options to be passed down to `live_file_input/2`","ref":"Surface.Components.LiveFileInput.html#module-properties"},{"type":"module","title":"Events - Surface.Components.LiveFileInput","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.LiveFileInput.html#module-events"},{"type":"function","title":"Surface.Components.LiveFileInput.render/1","doc":"","ref":"Surface.Components.LiveFileInput.html#render/1"},{"type":"module","title":"Surface.Components.Form.Checkbox","doc":"Defines a checkbox.\n\nProvides a wrapper for Phoenix.HTML.Form's `checkbox/3` function.\n\nAll options passed via `opts` will be sent to `checkbox/3`, `value` and\n`class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.Checkbox.html"},{"type":"module","title":"Examples - Surface.Components.Form.Checkbox","doc":"```\n \n```","ref":"Surface.Components.Form.Checkbox.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.Checkbox","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list\n* **checked_value** *:any, default: true* - The value to be sent when the checkbox is checked. Defaults to \"true\"\n* **hidden_input** *:boolean, default: true* - Controls if this function will generate a hidden input to submit the unchecked value or not, defaults to \"true\".\n* **unchecked_value** *:any, default: false* - The value to be sent when the checkbox is unchecked, defaults to \"false\".","ref":"Surface.Components.Form.Checkbox.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.Checkbox","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.Checkbox.html#module-events"},{"type":"function","title":"Surface.Components.Form.Checkbox.render/1","doc":"","ref":"Surface.Components.Form.Checkbox.html#render/1"},{"type":"module","title":"Surface.Components.Form.ColorInput","doc":"An input field that let the user specify a **color**, either with a\ntext field or a color picker interface.\n\nProvides a wrapper for Phoenix.HTML.Form's `color_input/3` function.\n\nAll options passed via `opts` will be sent to `color_input/3`, `value` and\n`class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.ColorInput.html"},{"type":"module","title":"Examples - Surface.Components.Form.ColorInput","doc":"```\n \n```","ref":"Surface.Components.Form.ColorInput.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.ColorInput","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.ColorInput.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.ColorInput","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.ColorInput.html#module-events"},{"type":"function","title":"Surface.Components.Form.ColorInput.render/1","doc":"","ref":"Surface.Components.Form.ColorInput.html#render/1"},{"type":"module","title":"Surface.Components.Form.DateInput","doc":"An input field that let the user enter a **date**, either with a text field\nor a date picker interface.\n\nProvides a wrapper for Phoenix.HTML.Form's `date_input/3` function.\n\nAll options passed via `opts` will be sent to `date_input/3`, `value` and\n`class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.DateInput.html"},{"type":"module","title":"Examples - Surface.Components.Form.DateInput","doc":"```\n \n```","ref":"Surface.Components.Form.DateInput.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.DateInput","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.DateInput.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.DateInput","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.DateInput.html#module-events"},{"type":"function","title":"Surface.Components.Form.DateInput.render/1","doc":"","ref":"Surface.Components.Form.DateInput.html#render/1"},{"type":"module","title":"Surface.Components.Form.DateSelect","doc":"Generates select tags for date.\n\nProvides a wrapper for Phoenix.HTML.Form's `date_select/3` function.\n\nAll options passed via `opts` will be sent to `date_select/3`,\n`value`, `default`, `year`, `month`, `day` and `builder`\ncan be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.DateSelect.html"},{"type":"module","title":"Examples - Surface.Components.Form.DateSelect","doc":"```\n \n\n \n   \n \n```","ref":"Surface.Components.Form.DateSelect.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.DateSelect","doc":"* **form** *:form, from_context: {Surface.Components.Form, :form}* - The form identifier\n* **id** *:string* - The id prefix for underlying select fields\n* **name** *:string* - The name prefix for underlying select fields\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - The field name\n* **value** *:any* - Value to pre-populate the select\n* **default** *:any* - Default value to use when none was given in 'value' and none is available in the form data\n* **year** *:keyword* - Options passed to the underlying 'year' select\n* **month** *:keyword* - Options passed to the underlying 'month' select\n* **day** *:keyword* - Options passed to the underlying 'day' select\n* **builder** *:fun* - Specify how the select can be build. It must be a function that receives a builder\nthat should be invoked with the select name and a set of options.\n\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.DateSelect.html#module-properties"},{"type":"function","title":"Surface.Components.Form.DateSelect.render/1","doc":"","ref":"Surface.Components.Form.DateSelect.html#render/1"},{"type":"module","title":"Surface.Components.Form.DateTimeLocalInput","doc":"An input field that let the user enter both **date** and **time**, using a\ntext field and a date picker interface.\n\nProvides a wrapper for Phoenix.HTML.Form's `datetime_local_input/3` function.\n\nAll options passed via `opts` will be sent to `datetime_local_input/3`, `value` and\n`class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.DateTimeLocalInput.html"},{"type":"module","title":"Examples - Surface.Components.Form.DateTimeLocalInput","doc":"```\n \n```","ref":"Surface.Components.Form.DateTimeLocalInput.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.DateTimeLocalInput","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.DateTimeLocalInput.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.DateTimeLocalInput","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.DateTimeLocalInput.html#module-events"},{"type":"function","title":"Surface.Components.Form.DateTimeLocalInput.render/1","doc":"","ref":"Surface.Components.Form.DateTimeLocalInput.html#render/1"},{"type":"module","title":"Surface.Components.Form.DateTimeSelect","doc":"Generates select tags for datetime.\n\nProvides a wrapper for Phoenix.HTML.Form's `datetime_select/3` function.\n\nAll options passed via `opts` will be sent to `datetime_select/3`,\n`value`, `default`, `year`, `month`, `day`, `hour`, `minute`, `second` and `builder`\ncan be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.DateTimeSelect.html"},{"type":"module","title":"Examples - Surface.Components.Form.DateTimeSelect","doc":"```\n \n\n \n   \n \n```","ref":"Surface.Components.Form.DateTimeSelect.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.DateTimeSelect","doc":"* **form** *:form, from_context: {Surface.Components.Form, :form}* - The form identifier\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - The field name\n* **id** *:string* - The id prefix for underlying select fields\n* **name** *:string* - The name prefix for underlying select fields\n* **value** *:any* - Value to pre-populate the select\n* **default** *:any* - Default value to use when none was given in 'value' and none is available in the form data\n* **year** *:keyword* - Options passed to the underlying 'year' select\n* **month** *:keyword* - Options passed to the underlying 'month' select\n* **day** *:keyword* - Options passed to the underlying 'day' select\n* **hour** *:keyword* - Options passed to the underlying 'day' select\n* **minute** *:keyword* - Options passed to the underlying 'day' select\n* **second** *:keyword* - Options passed to the underlying 'day' select\n* **builder** *:fun* - Specify how the select can be build. It must be a function that receives a builder\nthat should be invoked with the select name and a set of options.\n\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.DateTimeSelect.html#module-properties"},{"type":"function","title":"Surface.Components.Form.DateTimeSelect.render/1","doc":"","ref":"Surface.Components.Form.DateTimeSelect.html#render/1"},{"type":"module","title":"Surface.Components.Form.EmailInput","doc":"An input field that let the user enter one or multiple **e-mails**.\n\nProvides a wrapper for Phoenix.HTML.Form's `email_input/3` function.\n\nAll options passed via `opts` will be sent to `email_input/3`, `value` and\n`class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.EmailInput.html"},{"type":"module","title":"Examples - Surface.Components.Form.EmailInput","doc":"```\n \n```","ref":"Surface.Components.Form.EmailInput.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.EmailInput","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.EmailInput.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.EmailInput","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.EmailInput.html#module-events"},{"type":"function","title":"Surface.Components.Form.EmailInput.render/1","doc":"","ref":"Surface.Components.Form.EmailInput.html#render/1"},{"type":"module","title":"Surface.Components.Form.ErrorTag","doc":"A component inspired by `error_tag/3` that ships with `mix phx.new` in\n`MyAppWeb.ErrorHelpers`.\n\nRenders error messages if any exist regarding the given field.","ref":"Surface.Components.Form.ErrorTag.html"},{"type":"module","title":"Error Translation - Surface.Components.Form.ErrorTag","doc":"Changeset errors are translated using the default error translator\nthat ships with phoenix when generated with `mix phx.new --no-gettext`.\n\nWhen using Gettext, you can use configuration to route all errors through\nthe `MyAppWeb.ErrorHelpers.translate_error/1` function generated by Phoenix,\nwhich utilizes `Gettext`. You need to provide a tuple with the module and\nthe name of the function (as an atom) as follows:\n\n```elixir\nconfig :surface, :components, [\n  {Surface.Components.Form.ErrorTag, default_translator: {MyAppWeb.ErrorHelpers, :translate_error}}\n]\n```\n\n> **Note:** If you don't configure a `default_translator`, Surface will try to translate errors using\na built-in message translator which may not cover all types of errors. If the error cannot\nbe translated, a generic `\"invalid value\"` will be returned and a warning will be emitted,\nreminding the user to set up a proper `default_translator` that can handle such cases.\n\nThere is also a `translator` prop which can be used on a case-by-case basis.\nIt overrides the configuration.","ref":"Surface.Components.Form.ErrorTag.html#module-error-translation"},{"type":"module","title":"Examples - Surface.Components.Form.ErrorTag","doc":"```surface\n \n```\n\n```surface\n \n   \n \n```\n\n```surface\n \n```\n\n```surface\n \n```\n\n```surface\n \n```","ref":"Surface.Components.Form.ErrorTag.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.ErrorTag","doc":"* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the associated field\n* **class** *:css_class* - Classes to apply to each error tag  .\n\nThis can also be set via config, for example:\n\n```elixir\nconfig :surface, :components, [\n  {Surface.Components.Form.ErrorTag, default_class: \"invalid-feedback\"}\n]\n```\n\nHowever, the prop overrides the config value if provided.\n\n* **translator** *:fun* - A function that takes one argument `{msg, opts}` and returns\nthe translated error message as a string. If not provided, falls\nback to Phoenix's default implementation.\n\nThis can also be set via config, for example:\n\n```elixir\nconfig :surface, :components, [\n  {Surface.Components.Form.ErrorTag, default_translator: {MyApp.Gettext, :translate_error}}\n]\n```\n\n* **feedback_for** *:string* - If you changed the default ID on the input, provide it here.\n(Useful when there are multiple forms on the same page, each\nwith an input of the same name. LiveView will exhibit buggy behavior\nwithout assigning separate id's to each.)","ref":"Surface.Components.Form.ErrorTag.html#module-properties"},{"type":"function","title":"Surface.Components.Form.ErrorTag.render/1","doc":"","ref":"Surface.Components.Form.ErrorTag.html#render/1"},{"type":"function","title":"Surface.Components.Form.ErrorTag.translate_error/1","doc":"Translates an error message.\n\nThis is the fallback (Phoenix's default implementation) if a translator\nis not provided via config or the `translate` prop.","ref":"Surface.Components.Form.ErrorTag.html#translate_error/1"},{"type":"module","title":"Surface.Components.Form.Field","doc":"Defines a form field.\n\nThe `Field` component sets the provided field name into the context so child\ncomponents like input fields and labels can retrieve it and use it as\nthe default field.","ref":"Surface.Components.Form.Field.html"},{"type":"module","title":"Properties - Surface.Components.Form.Field","doc":"* **name** *:any, required: true* - The field name\n* **class** *:css_class* - The CSS class for the generated ` ` element","ref":"Surface.Components.Form.Field.html#module-properties"},{"type":"module","title":"Slots - Surface.Components.Form.Field","doc":"* **default, required: true** - The content for the field","ref":"Surface.Components.Form.Field.html#module-slots"},{"type":"function","title":"Surface.Components.Form.Field.render/1","doc":"","ref":"Surface.Components.Form.Field.html#render/1"},{"type":"module","title":"Surface.Components.Form.FieldContext","doc":"Defines a context for a form field but without the ` ` wrapper in `Field`.\n\nLike the `Field` component, sets the provided field name into the context\nso child components like input fields and labels can retrieve it and use it as\nthe default field.","ref":"Surface.Components.Form.FieldContext.html"},{"type":"module","title":"Properties - Surface.Components.Form.FieldContext","doc":"* **name** *:any, required: true* - The field name","ref":"Surface.Components.Form.FieldContext.html#module-properties"},{"type":"module","title":"Slots - Surface.Components.Form.FieldContext","doc":"* **default, required: true** - The content for the field","ref":"Surface.Components.Form.FieldContext.html#module-slots"},{"type":"function","title":"Surface.Components.Form.FieldContext.render/1","doc":"","ref":"Surface.Components.Form.FieldContext.html#render/1"},{"type":"module","title":"Surface.Components.Form.FileInput","doc":"Generates a file input.\n\nIt requires the given form to be configured with `multipart: true`.\n\nAll options passed via `opts` will be sent to `file_input/3`, `value` and\n`class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.FileInput.html"},{"type":"module","title":"Examples - Surface.Components.Form.FileInput","doc":"```\n \n   \n \n```","ref":"Surface.Components.Form.FileInput.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.FileInput","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.FileInput.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.FileInput","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.FileInput.html#module-events"},{"type":"function","title":"Surface.Components.Form.FileInput.render/1","doc":"","ref":"Surface.Components.Form.FileInput.html#render/1"},{"type":"module","title":"Surface.Components.Form.HiddenInput","doc":"A **hidden** input field.\n\nProvides a wrapper for Phoenix.HTML.Form's `hidden_input/3` function.\n\nAll options passed via `opts` will be sent to `hidden_input/3`, `value` and\n`class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.HiddenInput.html"},{"type":"module","title":"Examples - Surface.Components.Form.HiddenInput","doc":"```\n \n```","ref":"Surface.Components.Form.HiddenInput.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.HiddenInput","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.HiddenInput.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.HiddenInput","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.HiddenInput.html#module-events"},{"type":"function","title":"Surface.Components.Form.HiddenInput.render/1","doc":"","ref":"Surface.Components.Form.HiddenInput.html#render/1"},{"type":"module","title":"Surface.Components.Form.HiddenInputs","doc":"A wrapper for `Phoenix.HTML.Form.html.hidden_inputs_for/1`.\n\nGenerates hidden inputs for the given form.","ref":"Surface.Components.Form.HiddenInputs.html"},{"type":"module","title":"Properties - Surface.Components.Form.HiddenInputs","doc":"* **for** *:form, from_context: {Surface.Components.Form, :form}* - The form.\n\nIt should either be a `Phoenix.HTML.Form` emitted by `form_for`, `inputs_for` or an atom.","ref":"Surface.Components.Form.HiddenInputs.html#module-properties"},{"type":"function","title":"Surface.Components.Form.HiddenInputs.render/1","doc":"","ref":"Surface.Components.Form.HiddenInputs.html#render/1"},{"type":"module","title":"Surface.Components.Form.Inputs","doc":"A wrapper for `Phoenix.HTML.Form.html.inputs_for/3`.\n\nAdditionally, adds the generated form instance that is returned by `inputs_for/3`\ninto the context, making it available to any child input.","ref":"Surface.Components.Form.Inputs.html"},{"type":"module","title":"Properties - Surface.Components.Form.Inputs","doc":"* **form** *:form, from_context: {Form, :form}* - The parent form.\n\nIt should either be a `Phoenix.HTML.Form` emitted by `form_for` or an atom.\n\n* **for** *:any, from_context: {Field, :field}* - An atom or string representing the field related to the child inputs.\n\n* **opts** *:keyword, default: []* - Extra options for `inputs_for/1`.\n\nSee `Phoenix.Component.inputs_for/1` for the available options.","ref":"Surface.Components.Form.Inputs.html#module-properties"},{"type":"module","title":"Slots - Surface.Components.Form.Inputs","doc":"* **default, arg: %{form: :form, index: :integer}** - The code containing the input controls","ref":"Surface.Components.Form.Inputs.html#module-slots"},{"type":"function","title":"Surface.Components.Form.Inputs.render/1","doc":"","ref":"Surface.Components.Form.Inputs.html#render/1"},{"type":"module","title":"Surface.Components.Form.Label","doc":"Defines a label.\n\nProvides similar capabilities to Phoenix's built-in `label/2`\nfunction.\n\nOption `class` can be set directly and will override anything in `opts`.\n\nAll given options are forwarded to the underlying tag. A default value is\nprovided for for attribute but can be overridden if you pass a value to the\nfor option. Text content would be inferred from field if not specified.","ref":"Surface.Components.Form.Label.html"},{"type":"module","title":"Properties - Surface.Components.Form.Label","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - The form identifier\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - The field name\n* **class** *:css_class* - The CSS class for the underlying tag\n* **text** *:any* - The text for the generated ` ` element, if no content (default slot) is provided.\n\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.Label.html#module-properties"},{"type":"module","title":"Slots - Surface.Components.Form.Label","doc":"* **default** - The text for the label","ref":"Surface.Components.Form.Label.html#module-slots"},{"type":"module","title":"Events - Surface.Components.Form.Label","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.Label.html#module-events"},{"type":"function","title":"Surface.Components.Form.Label.render/1","doc":"","ref":"Surface.Components.Form.Label.html#render/1"},{"type":"module","title":"Surface.Components.Form.MultipleSelect","doc":"Defines a select.\n\nProvides a wrapper for Phoenix.HTML.Form's `multiple_select/4` function.\n\nAll options passed via `opts` will be sent to `multiple_select/4`, `class` can\nbe set directly and will override anything in `opts`.","ref":"Surface.Components.Form.MultipleSelect.html"},{"type":"module","title":"Properties - Surface.Components.Form.MultipleSelect","doc":"* **form** *:form, from_context: {Surface.Components.Form, :form}* - The form identifier\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - The field name\n* **id** *:string* - The id of the corresponding select field\n* **name** *:string* - The name of the corresponding select field\n* **class** *:css_class* - The CSS class for the underlying tag\n* **options** *:any, default: []* - The options in the select\n* **selected** *:any* - The default selected option\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.MultipleSelect.html#module-properties"},{"type":"function","title":"Surface.Components.Form.MultipleSelect.render/1","doc":"","ref":"Surface.Components.Form.MultipleSelect.html#render/1"},{"type":"module","title":"Surface.Components.Form.NumberInput","doc":"An input field that let the user to enter a **number**.\n\nProvides a wrapper for Phoenix.HTML.Form's `number_input/3` function.\n\nAll options passed via `opts` will be sent to `number_input/3`, `value` and\n`class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.NumberInput.html"},{"type":"module","title":"Examples - Surface.Components.Form.NumberInput","doc":"```\n \n```","ref":"Surface.Components.Form.NumberInput.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.NumberInput","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.NumberInput.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.NumberInput","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.NumberInput.html#module-events"},{"type":"function","title":"Surface.Components.Form.NumberInput.render/1","doc":"","ref":"Surface.Components.Form.NumberInput.html#render/1"},{"type":"module","title":"Surface.Components.Form.OptionsForSelect","doc":"Defines options to be used inside a select.\n\nThis is useful when building the select by hand.\n\nProvides a wrapper for Phoenix.HTML.Form's `options_for_select/2` function.","ref":"Surface.Components.Form.OptionsForSelect.html"},{"type":"module","title":"Properties - Surface.Components.Form.OptionsForSelect","doc":"* **options** *:any, default: []* - The options in the select\n* **selected** *:any, default: nil* - The selected values","ref":"Surface.Components.Form.OptionsForSelect.html#module-properties"},{"type":"function","title":"Surface.Components.Form.OptionsForSelect.render/1","doc":"","ref":"Surface.Components.Form.OptionsForSelect.html#render/1"},{"type":"module","title":"Surface.Components.Form.PasswordInput","doc":"An input field that let the user securely specify a **password**.\n\nProvides a wrapper for Phoenix.HTML.Form's `password_input/3` function.\n\nAll options passed via `opts` will be sent to `password_input/3`, `value` and\n`class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.PasswordInput.html"},{"type":"module","title":"Examples - Surface.Components.Form.PasswordInput","doc":"```\n \n```","ref":"Surface.Components.Form.PasswordInput.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.PasswordInput","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.PasswordInput.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.PasswordInput","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.PasswordInput.html#module-events"},{"type":"function","title":"Surface.Components.Form.PasswordInput.render/1","doc":"","ref":"Surface.Components.Form.PasswordInput.html#render/1"},{"type":"module","title":"Surface.Components.Form.RadioButton","doc":"Defines a radio button.\n\nProvides a wrapper for Phoenix.HTML.Form's `radio_button/4` function.\n\nAll options passed via `opts` will be sent to `radio_button/4`, `value` and\n`class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.RadioButton.html"},{"type":"module","title":"Examples - Surface.Components.Form.RadioButton","doc":"```\n \n```","ref":"Surface.Components.Form.RadioButton.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.RadioButton","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list\n* **checked** *:boolean* - Indicates whether or not the radio button is the selected item in the group","ref":"Surface.Components.Form.RadioButton.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.RadioButton","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.RadioButton.html#module-events"},{"type":"function","title":"Surface.Components.Form.RadioButton.render/1","doc":"","ref":"Surface.Components.Form.RadioButton.html#render/1"},{"type":"module","title":"Surface.Components.Form.RangeInput","doc":"An input field that let the user specify a numeric value in a given **range**,\nusually using a slider.\n\nProvides a wrapper for Phoenix.HTML.Form's `range_input/3` function.\n\nAll options passed via `opts` will be sent to `range_input/3`, `value`, `min`, `max`\nand `class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.RangeInput.html"},{"type":"module","title":"Examples - Surface.Components.Form.RangeInput","doc":"```\n \n```","ref":"Surface.Components.Form.RangeInput.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.RangeInput","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list\n* **min** *:string* - Minimum value for the input\n* **max** *:string* - Maximum value for the input\n* **step** *:string* - Sets or returns the value of the step attribute of the slider control","ref":"Surface.Components.Form.RangeInput.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.RangeInput","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.RangeInput.html#module-events"},{"type":"function","title":"Surface.Components.Form.RangeInput.render/1","doc":"","ref":"Surface.Components.Form.RangeInput.html#render/1"},{"type":"module","title":"Surface.Components.Form.Reset","doc":"Defines a reset button.\n\nProvides a wrapper for Phoenix.HTML.Form's `reset/2` function.\n\nAll options passed via `opts` will be sent to `reset/2`, `value` and\n`class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.Reset.html"},{"type":"module","title":"Examples - Surface.Components.Form.Reset","doc":"```\n \n```","ref":"Surface.Components.Form.Reset.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.Reset","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string, default: \"Reset\"* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Keyword list with options to be passed down to `reset/2`","ref":"Surface.Components.Form.Reset.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.Reset","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.Reset.html#module-events"},{"type":"function","title":"Surface.Components.Form.Reset.render/1","doc":"","ref":"Surface.Components.Form.Reset.html#render/1"},{"type":"module","title":"Surface.Components.Form.SearchInput","doc":"An input field that let the user enter **search** queries.\n\nProvides a wrapper for Phoenix.HTML.Form's `search_input/3` function.\n\nAll options passed via `opts` will be sent to `search_input/3`, `value` and\n`class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.SearchInput.html"},{"type":"module","title":"Examples - Surface.Components.Form.SearchInput","doc":"```\n \n```","ref":"Surface.Components.Form.SearchInput.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.SearchInput","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.SearchInput.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.SearchInput","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.SearchInput.html#module-events"},{"type":"function","title":"Surface.Components.Form.SearchInput.render/1","doc":"","ref":"Surface.Components.Form.SearchInput.html#render/1"},{"type":"module","title":"Surface.Components.Form.Select","doc":"Defines a select.\n\nProvides a wrapper for Phoenix.HTML.Form's `select/4` function.\n\nAll options passed via `opts` will be sent to `select/4`, `class` can\nbe set directly and will override anything in `opts`.","ref":"Surface.Components.Form.Select.html"},{"type":"module","title":"Properties - Surface.Components.Form.Select","doc":"* **form** *:form, from_context: {Surface.Components.Form, :form}* - The form identifier\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - The field name\n* **id** *:string* - The id of the corresponding select field\n* **name** *:string* - The name of the corresponding select field\n* **class** *:css_class* - The CSS class for the underlying tag\n* **options** *:any, default: []* - The options in the select\n* **prompt** *:string* - An option to include at the top of the options with the given prompt text\n* **selected** *:any* - The default value to use when none was sent as parameter\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.Select.html#module-properties"},{"type":"function","title":"Surface.Components.Form.Select.render/1","doc":"","ref":"Surface.Components.Form.Select.html#render/1"},{"type":"module","title":"Surface.Components.Form.Submit","doc":"Defines a submit button to send the form.\n\nAll options are forwarded to the underlying ` `","ref":"Surface.Components.Form.Submit.html"},{"type":"module","title":"Properties - Surface.Components.Form.Submit","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **label** *:string* - The label to be used in the button\n* **class** *:css_class* - Class or classes to apply to the button\n* **opts** *:keyword, default: []* - Keyword list with options to be passed down to ` `","ref":"Surface.Components.Form.Submit.html#module-properties"},{"type":"module","title":"Slots - Surface.Components.Form.Submit","doc":"* **default** - Slot used for having children other than plain text in the button","ref":"Surface.Components.Form.Submit.html#module-slots"},{"type":"module","title":"Events - Surface.Components.Form.Submit","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.Submit.html#module-events"},{"type":"function","title":"Surface.Components.Form.Submit.render/1","doc":"","ref":"Surface.Components.Form.Submit.html#render/1"},{"type":"module","title":"Surface.Components.Form.TelephoneInput","doc":"An input field that let the user enter a **telephone number**.\n\nProvides a wrapper for Phoenix.HTML.Form's `telephone_input/3` function.\n\nAll options passed via `opts` will be sent to `telephone_input/3`, `value`,\n`pattern` and `class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.TelephoneInput.html"},{"type":"module","title":"Examples - Surface.Components.Form.TelephoneInput","doc":"```\n \n```","ref":"Surface.Components.Form.TelephoneInput.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.TelephoneInput","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list\n* **pattern** *:string* - A regular expression to validate the entered value","ref":"Surface.Components.Form.TelephoneInput.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.TelephoneInput","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.TelephoneInput.html#module-events"},{"type":"function","title":"Surface.Components.Form.TelephoneInput.render/1","doc":"","ref":"Surface.Components.Form.TelephoneInput.html#render/1"},{"type":"module","title":"Surface.Components.Form.TextArea","doc":"An input field that let the user enter a **multi-line** text.\n\nProvides a wrapper for Phoenix.HTML.Form's `textarea/3` function.\n\nAll options passed via `opts` will be sent to `textarea/3`. Explicitly\ndefined properties like `value` and `class` can be set directly and will\noverride anything in `opts`.","ref":"Surface.Components.Form.TextArea.html"},{"type":"module","title":"Examples - Surface.Components.Form.TextArea","doc":"```\n \n```","ref":"Surface.Components.Form.TextArea.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.TextArea","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list\n* **rows** *:string* - Specifies the visible number of lines in a text area\n* **cols** *:string* - Specifies the visible width of a text area","ref":"Surface.Components.Form.TextArea.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.TextArea","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.TextArea.html#module-events"},{"type":"function","title":"Surface.Components.Form.TextArea.render/1","doc":"","ref":"Surface.Components.Form.TextArea.html#render/1"},{"type":"module","title":"Surface.Components.Form.TextInput","doc":"An input field that let the user enter a **single-line text**.\n\nProvides a wrapper for Phoenix.HTML.Form's `text_input/3` function.\n\nAll options passed via `opts` will be sent to `text_input/3`, `value` and\n`class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.TextInput.html"},{"type":"module","title":"Examples - Surface.Components.Form.TextInput","doc":"```\n \n```","ref":"Surface.Components.Form.TextInput.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.TextInput","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.TextInput.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.TextInput","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.TextInput.html#module-events"},{"type":"function","title":"Surface.Components.Form.TextInput.render/1","doc":"","ref":"Surface.Components.Form.TextInput.html#render/1"},{"type":"module","title":"Surface.Components.Form.TimeInput","doc":"An input field that let the user enter a **time** (hours, minutes and\noptionally seconds).\n\nProvides a wrapper for Phoenix.HTML.Form's `time_input/3` function.\n\nAll options passed via `opts` will be sent to `time_input/3`, `value` and\n`class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.TimeInput.html"},{"type":"module","title":"Examples - Surface.Components.Form.TimeInput","doc":"```\n \n```","ref":"Surface.Components.Form.TimeInput.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.TimeInput","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.TimeInput.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.TimeInput","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.TimeInput.html#module-events"},{"type":"function","title":"Surface.Components.Form.TimeInput.render/1","doc":"","ref":"Surface.Components.Form.TimeInput.html#render/1"},{"type":"module","title":"Surface.Components.Form.TimeSelect","doc":"Generates select tags for time.\n\nProvides a wrapper for Phoenix.HTML.Form's `time_select/3` function.\n\nAll options passed via `opts` will be sent to `time_select/3`,\n`value`, `default`, `hour`, `minute`, `second` and `builder`\ncan be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.TimeSelect.html"},{"type":"module","title":"Examples - Surface.Components.Form.TimeSelect","doc":"```\n \n\n \n   \n \n```","ref":"Surface.Components.Form.TimeSelect.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.TimeSelect","doc":"* **form** *:form, from_context: {Surface.Components.Form, :form}* - The form identifier\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - The field name\n* **id** *:string* - The id prefix for underlying select fields\n* **name** *:string* - The name prefix for underlying select fields\n* **value** *:any* - Value to pre-populate the select\n* **default** *:any* - Default value to use when none was given in 'value' and none is available in the form data\n* **hour** *:keyword* - Options passed to the underlying 'day' select\n* **minute** *:keyword* - Options passed to the underlying 'day' select\n* **second** *:keyword* - Options passed to the underlying 'day' select\n* **builder** *:fun* - Specify how the select can be build. It must be a function that receives a builder\nthat should be invoked with the select name and a set of options.\n\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.TimeSelect.html#module-properties"},{"type":"function","title":"Surface.Components.Form.TimeSelect.render/1","doc":"","ref":"Surface.Components.Form.TimeSelect.html#render/1"},{"type":"module","title":"Surface.Components.Form.UrlInput","doc":"An input field that let the user enter a **URL**.\n\nProvides a wrapper for Phoenix.HTML.Form's `url_input/3` function.\n\nAll options passed via `opts` will be sent to `url_input/3`, `value` and\n`class` can be set directly and will override anything in `opts`.","ref":"Surface.Components.Form.UrlInput.html"},{"type":"module","title":"Examples - Surface.Components.Form.UrlInput","doc":"```\n \n```","ref":"Surface.Components.Form.UrlInput.html#module-examples"},{"type":"module","title":"Properties - Surface.Components.Form.UrlInput","doc":"* **values** *:keyword, default: []* - List values that will be sent as part of the payload triggered by an event\n* **form** *:form, from_context: {Surface.Components.Form, :form}* - An identifier for the form\n* **field** *:any, from_context: {Surface.Components.Form.Field, :field}* - An identifier for the input\n* **id** *:string* - The id of the corresponding input field\n* **name** *:string* - The name of the corresponding input field\n* **value** *:string* - Value to pre-populated the input\n* **class** *:css_class* - Class or classes to apply to the input\n* **opts** *:keyword, default: []* - Options list","ref":"Surface.Components.Form.UrlInput.html#module-properties"},{"type":"module","title":"Events - Surface.Components.Form.UrlInput","doc":"* **click** - Triggered when the component receives click\n* **click_away** - Triggered when a click event happens outside of the element\n* **capture_click** - Triggered when the component captures click\n* **blur** - Triggered when the component loses focus\n* **focus** - Triggered when the component receives focus\n* **window_blur** - Triggered when the page loses focus\n* **window_focus** - Triggered when the page receives focus\n* **keydown** - Triggered when a key on the keyboard is pressed\n* **keyup** - Triggered when a key on the keyboard is released\n* **window_keydown** - Triggered when a key on the keyboard is pressed (window-level)\n* **window_keyup** - Triggered when a key on the keyboard is released (window-level)","ref":"Surface.Components.Form.UrlInput.html#module-events"},{"type":"function","title":"Surface.Components.Form.UrlInput.render/1","doc":"","ref":"Surface.Components.Form.UrlInput.html#render/1"},{"type":"module","title":"Surface.Components.Form.Input.InputContext","doc":"Retrieves `form` and `field` values from the context.\n\nThis module is deprecated. Use option `from_context` instead. Example:\n\n    prop form, :form, from_context: {Form, :form}","ref":"Surface.Components.Form.Input.InputContext.html"},{"type":"module","title":"Properties - Surface.Components.Form.Input.InputContext","doc":"* **assigns** *:map* - The assigns of the host component","ref":"Surface.Components.Form.Input.InputContext.html#module-properties"},{"type":"module","title":"Slots - Surface.Components.Form.Input.InputContext","doc":"* **default, arg: %{form: :form, field: :any}** - The code containing the input control","ref":"Surface.Components.Form.Input.InputContext.html#module-slots"},{"type":"function","title":"Surface.Components.Form.Input.InputContext.render/1","doc":"","ref":"Surface.Components.Form.Input.InputContext.html#render/1"},{"type":"extras","title":"Surface.Form","doc":"# Surface.Form\n\nSurface wrappers for legacy `Phoenix.HTML.Form` functions.\n\n> [!NOTE]\n> This library is maintained only for compatibility and does not accept new features.\n> We strongly recommend using the new built-in [<.form>](https://hexdocs.pm/phoenix_live_view/Phoenix.Component.html#form/)\n> component, along with [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) and\n> [Phoenix.HTML.FormField](https://hexdocs.pm/phoenix_html/Phoenix.HTML.FormField.html) structs. If you're\n> not able to update all your forms at once, then this library can be used as a safe fallback so you can\n> gradually replace them.","ref":"readme.html"},{"type":"extras","title":"Installation - Surface.Form","doc":"Add `surface_form_helpers` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:surface_form_helpers, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"License - Surface.Form","doc":"Copyright (c) 2024, Marlus Saraiva.\n\nSurface source code is licensed under the [MIT License](LICENSE.md).","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.1.0 (2024-09-24) - Changelog","doc":"* Initial version extracted from Surface `v0.11.5`","ref":"changelog.html#v0-1-0-2024-09-24"},{"type":"extras","title":"MIT License","doc":"# MIT License\n\nCopyright (c) 2024 Marlus Saraiva\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}